@@ -42,8 +42,8 @@ has static    => sub { Mojolicious::Static->new };
 has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
-our $CODENAME = 'Clinking Beer Mugs';
-our $VERSION  = '6.66';
+our $CODENAME = 'Doughnut';
+our $VERSION  = '7.0';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -190,7 +190,7 @@ sub _exception {
   $c->helpers->reply->exception($@) unless eval { $next->(); 1 };
 }
 
-"Ph'nglui mglw'nafh Cthulhu R'lyeh wgah'nagl fhtagn";
+1;
 
 =encoding utf8
 
@@ -222,6 +222,12 @@ Mojolicious - Real-time web framework
 
 =head1 DESCRIPTION
 
+An amazing real-time web framework built on top of the powerful L<Mojo> web
+development toolkit. With support for RESTful routes, plugins, commands,
+Perl-ish templates, content negotiation, session management, form validation,
+testing framework, static file server, C<CGI>/C<PSGI> detection, first class
+Unicode support and much more for you to discover.
+
 Take a look at our excellent documentation in L<Mojolicious::Guides>!
 
 =head1 HOOKS
@@ -718,6 +724,8 @@ L<http://www.apache.org/licenses/LICENSE-2.0>.
 Every major release of L<Mojolicious> has a code name, these are the ones that
 have been used in the past.
 
+7.0, C<Doughnut> (U+1F369)
+
 6.0, C<Clinking Beer Mugs> (U+1F37B)
 
 5.0, C<Tiger Face> (U+1F42F)
